@@ -3,7 +3,7 @@ use warnings;
 use version;
 
 package WebService::Nestoria::Search;
-$WebService::Nestoria::Search::VERSION = '1.022010';
+$WebService::Nestoria::Search::VERSION = '1.022011';
 use Carp;
 use URI;
 use WebService::Nestoria::Search::Request;
@@ -15,7 +15,7 @@ WebService::Nestoria::Search - Perl interface to the Nestoria Search public API.
 
 =head1 VERSION
 
-version 1.022010
+version 1.022011
 
 =head1 SYNOPSIS
 
@@ -175,6 +175,7 @@ my %Config = (
 
 ## filled in Search/Request.pm
 our $RecentRequestUrl;
+our $SleepTime = 2;
 
 my %GlobalDefaults = (
     'warnings'                => '1',
@@ -632,6 +633,60 @@ sub last_request_url {
     return $RecentRequestUrl;
 }
 
+=head2 override_user_agent
+
+Takes an LWP::UserAgent-ish object and uses that object for all requests.
+
+Note this is a class method so will affect all instances being used in your
+process.
+
+    WebService::Nestoria::Search->override_user_agent($UA);
+
+=cut
+
+sub override_user_agent {
+    my $class = shift;
+    my $UA = shift;
+
+    # allow getting called as ::override_user_agent() instead of
+    # ->override_user_agent() - we're nice like that :-)
+    if (!$UA && $class->can("get")) {
+        $UA = $class;
+    }
+
+    $WebService::Nestoria::Search::Request::UA = $UA;
+
+    return;
+}
+
+=head2 override_sleep_time
+
+Takes a time in seconds to sleep between each request. The default is two
+(2) seconds.
+
+Note that the T&Cs of the Nestoria API explicitly request 1 second between
+requests. To live this requirement contact Nestoria.
+
+    WebService::Nestoria::Search->override_sleep_time(1);
+
+=cut
+
+sub override_sleep_time {
+    my $class = shift;
+    my $sleep_time = shift;
+
+    # allow getting called as ::override_user_agent() instead of
+    # ->override_user_agent() - we're nice like that :-)
+    if (!defined($sleep_time) && !ref($class) && $class =~ m/^\d+$/) {
+        $sleep_time = $class;
+    }
+
+    $WebService::Nestoria::Search::SleepTime = $sleep_time;
+
+    return;
+}
+
+
 =head1 Warnings
 
 Warnings is true by default, and means that errors are output to STDERR as well as being returned via $@. This can be turned off either on the C<use> line
